<?php
/**
 * @version    4.1.0
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2022 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Component\AllVideoShare\Site\Model;

// No direct access
\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ItemModel;
use \Joomla\CMS\Object\CMSObject;
use \Joomla\CMS\Table\Table;
use \Joomla\Utilities\ArrayHelper;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareQuery;

/**
 * Class VideoModel.
 *
 * @since  4.1.0
 */
class VideoModel extends ItemModel {

	public $_item;	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return  void
	 *
	 * @since   4.1.0
	 * @throws  Exception
	 */
	protected function populateState() {
		$app = Factory::getApplication();

		$params = $app->getParams();

		// Filter state information
		$alias = $app->input->getCmd( 'slg' );
		$id = AllVideoShareQuery::getVideoIdByAlias( $alias );
		$this->setState( 'video.id', $id );

		// Load the parameters
		$this->setState( 'params', $params );
	}	

	/**
	 * Method to get an object.
	 *
	 * @param   integer  $id  The id of the object to get.
	 *
	 * @return  mixed    Object on success, false on failure.
	 *
	 * @since   4.1.0
	 * @throws  Exception
	 */
	public function getItem( $id = null ) {
		if ( $this->_item === null ) {
			if ( empty( $id ) ) {
				$id = $this->getState( 'video.id' );
			}

			if ( empty( $id ) ) {
				return null;
			}

			$db = Factory::getDbo();
			$user = Factory::getUser();							

			$query = $db->getQuery( true );

			$query->select( '*' );
			$query->from( $db->quoteName( '#__allvideoshare_videos' ) );
			$query->where( 'id = ' . (int) $id );
			$query->where( '(user = ' . $db->quote( $user->username ) . ' OR  state = 1)' );

        	$db->setQuery( $query );
			$this->_item = $db->loadObject();
		}	
		
		if ( ! empty( $this->_item ) ) {
			if ( isset( $this->_item->catid ) && ! empty( $this->_item->catid ) ) {
				if ( $category = AllVideoShareQuery::getCategory( $this->_item->catid ) ) {
					$this->_item->category = $category;
				}
			}
	
			if ( isset( $this->_item->catids ) && ! empty( $this->_item->catids ) ) {
				$this->_item->catids = explode( ' ', trim( $this->_item->catids ) );
	
				$this->_item->categories = array();
	
				foreach ( $this->_item->catids as $catid ) {
					if ( $category = AllVideoShareQuery::getCategory( $catid ) ) {
						$this->_item->categories[] = $category;
					}
				}
			}
		}

		return $this->_item;
	}

	/**
	 * Get an instance of Table class
	 *
	 * @param   string  $type    Name of the Table class to get an instance of.
	 * @param   string  $prefix  Prefix for the table class name. Optional.
	 * @param   array   $config  Array of configuration values for the Table object. Optional.
	 *
	 * @return  Table|bool  Table if success, false on failure.
	 * 
	 * @since   4.1.0
	 */
	public function getTable( $type = 'Video', $prefix = 'Administrator', $config = array() ) {
		return parent::getTable( $type, $prefix, $config );
	}	
	
}
